==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/autoaway/translations/autoaway_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Prüfe auf Inaktivität alle</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Setze &quot;Abwesend&quot; nach</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Setzte Zustand &quot;Unsichtbar&quot; nach</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Neue Beschreibung</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n Sekunde</numerusform>
            <numerusform>%n Sekunden</numerusform>
        </translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Nicht ändern</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Untätigkeit</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Aktualisierung des Status alle</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation>Status &quot;Abwesend&quot; setzen</translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation>
            <numerusform>%n Minute</numerusform>
            <numerusform>%n Minuten</numerusform>
        </translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation>Status &quot;Unsichtbar&quot; setzen</translation>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation>Status &quot;Offline&quot; setzen</translation>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation>Setze &quot;Offline&quot; nach</translation>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation>Statusbeschreibung, wenn inaktiv</translation>
    </message>
    <message>
        <source>Prepend</source>
        <translation>Voranstellen</translation>
    </message>
    <message>
        <source>Append</source>
        <translation>Anhängen</translation>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Nicht erneuern</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/autoaway/translations/autoaway_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Zustand</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Prüfe auf Inaktivität alle</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Setze &quot;Abwesend&quot; nach</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Setzte Zustand &quot;Unsichtbar&quot; nach</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Neue Beschreibung</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n Sekunde</numerusform><numerusform>%n Sekunden</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Nicht ändern</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Verhalten</translation>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Untätigkeit</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Aktualisierung des Status alle</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation>Status &quot;Abwesend&quot; setzen</translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n Minute</numerusform><numerusform>%n Minuten</numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation>Status &quot;Unsichtbar&quot; setzen</translation>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation>Status &quot;Offline&quot; setzen</translation>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation>Setze &quot;Offline&quot; nach</translation>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation>Statusbeschreibung, wenn inaktiv</translation>
    </message>
    <message>
        <source>Prepend</source>
        <translation>Voranstellen</translation>
    </message>
    <message>
        <source>Append</source>
        <translation>Anhängen</translation>
    </message>
</context>
<context>
    <name>AutoawayConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
